@@ -32,7 +32,7 @@
     <message>
         <location filename="../advancedsettings.ui" line="80"/>
         <source>Some notifications set their own on-screen duration.</source>
-        <translation>Nogle notifikationer sætter deres egen varighed for hvor længe de blive vist på skærmen.</translation>
+        <translation>Nogle underretninger sætter deres egen varighed for hvor længe de blive vist på skærmen.</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="92"/>
@@ -47,7 +47,7 @@
     <message>
         <location filename="../advancedsettings.ui" line="127"/>
         <source>Unattended Notifications</source>
-        <translation>Notifikationer uden opsyn</translation>
+        <translation>Ikke-tilsete underretninger</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="135"/>
@@ -58,7 +58,7 @@
         <location filename="../advancedsettings.ui" line="149"/>
         <location filename="../advancedsettings.ui" line="159"/>
         <source>Application name is on the top of notification.</source>
-        <translation>Programnavnet er øverst i notifikationen.</translation>
+        <translation>Programnavnet er øverst i underretningen.</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="152"/>
@@ -87,27 +87,27 @@
         <location filename="../basicsettings.cpp" line="56"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
-        <translation>&lt;b&gt;Advarsel:&lt;/b&gt; der kører ikke noget notifikationsbaggrundsprogram.
+        <translation>&lt;b&gt;Advarsel:&lt;/b&gt; der kører ikke noget underretningsbaggrundsprogram.
 En reserve vil blive brugt.</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="59"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
-        <translation>&lt;b&gt;Advarsel:&lt;/b&gt; der kører et tredjeparts notifikationsbaggrundsprogram (%1).
+        <translation>&lt;b&gt;Advarsel:&lt;/b&gt; der kører et tredjeparts underretningsbaggrundsprogram (%1).
 Disse indstillinger vil ikke have nogen effekt på det!</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="112"/>
         <source>Notification demo </source>
-        <translation>Notifikationsdemo </translation>
+        <translation>Underretningsdemo </translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="113"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
-        <translation>Dette er en test-notifikation.
- Alle notifikationer vises her i LXQt.</translation>
+        <translation>Dette er en test-underretning.
+ Alle underretninger vises her i LXQt.</translation>
     </message>
 </context>
 <context>
@@ -115,7 +115,7 @@ Disse indstillinger vil ikke have nogen effekt på det!</translation>
     <message>
         <location filename="../mainwindow.cpp" line="41"/>
         <source>Desktop Notifications</source>
-        <translation>Skrivebordsnotifikationer</translation>
+        <translation>Skrivebordsunderretninger</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="44"/>
