@@ -17,17 +17,17 @@
         <location filename="../advancedsettings.ui" line="32"/>
         <location filename="../advancedsettings.ui" line="56"/>
         <source> px</source>
-        <translation> pixel</translation>
+        <translation> px</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="49"/>
         <source>Spacing:</source>
-        <translation>Térköz:</translation>
+        <translation>Helyköz:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="68"/>
         <source>Duration</source>
-        <translation>Tartam</translation>
+        <translation>Időtartam</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="80"/>
@@ -37,7 +37,7 @@
     <message>
         <location filename="../advancedsettings.ui" line="92"/>
         <source>Default duration:</source>
-        <translation>Alapértelmezett tartam:</translation>
+        <translation>Alapértelmezett időtartam:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="99"/>
@@ -47,28 +47,28 @@
     <message>
         <location filename="../advancedsettings.ui" line="127"/>
         <source>Unattended Notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Olvasatlan értesítések</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="135"/>
         <source>How many to save:</source>
-        <translation type="unfinished"></translation>
+        <translation>Értesítési előzmények:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="149"/>
         <location filename="../advancedsettings.ui" line="159"/>
         <source>Application name is on the top of notification.</source>
-        <translation type="unfinished"></translation>
+        <translation>Az alkalmazás neve az értesítés tetején látható.</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="152"/>
         <source>Ignore these applications:</source>
-        <translation type="unfinished"></translation>
+        <translation>Hagyja figyelmen kívül ezeket az alkalmazásokat:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="162"/>
         <source>app1,app2,app3</source>
-        <translation type="unfinished"></translation>
+        <translation>alkalmazás1,alkalmazás2,alkalmazás3,</translation>
     </message>
 </context>
 <context>
@@ -81,14 +81,14 @@
     <message>
         <location filename="../basicsettings.ui" line="30"/>
         <source>Position on screen</source>
-        <translation>Hely</translation>
+        <translation>Helyzet</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="56"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Értesítő démon nem fut.
-A vésztartalék használatos.</translation>
+A tartalék használatos.</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="59"/>
