@@ -17,12 +17,12 @@
         <location filename="../advancedsettings.ui" line="32"/>
         <location filename="../advancedsettings.ui" line="56"/>
         <source> px</source>
-        <translation type="unfinished"></translation>
+        <translation> ピクセル</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="49"/>
         <source>Spacing:</source>
-        <translation>空白:</translation>
+        <translation>余白:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="68"/>
@@ -47,28 +47,28 @@
     <message>
         <location filename="../advancedsettings.ui" line="127"/>
         <source>Unattended Notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>未確認の通知</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="135"/>
         <source>How many to save:</source>
-        <translation type="unfinished"></translation>
+        <translation>保存する件数:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="149"/>
         <location filename="../advancedsettings.ui" line="159"/>
         <source>Application name is on the top of notification.</source>
-        <translation type="unfinished"></translation>
+        <translation>アプリケーションの名前は、表示された通知の一番上にあります。</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="152"/>
         <source>Ignore these applications:</source>
-        <translation type="unfinished"></translation>
+        <translation>無視するアプリケーション:</translation>
     </message>
     <message>
         <location filename="../advancedsettings.ui" line="162"/>
         <source>app1,app2,app3</source>
-        <translation type="unfinished"></translation>
+        <translation>app1,app2,app3</translation>
     </message>
 </context>
 <context>
@@ -81,7 +81,7 @@
     <message>
         <location filename="../basicsettings.ui" line="30"/>
         <source>Position on screen</source>
-        <translation>スクリーン上での位置</translation>
+        <translation>画面上での位置</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="56"/>
@@ -95,7 +95,7 @@ A fallback will be used.</source>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;警告:&lt;/b&gt; サードパーティーの通知デーモン (%1) が実行されています。
-これらの設定は影響をおよぼしません!</translation>
+ここでの設定は影響をおよぼしません！</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="112"/>
@@ -107,7 +107,7 @@ These settings won&apos;t have any effect on it!</source>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>これは通知のテストです。
- 全ての通知はLXQtデスクトップのこの場所に表示されます。</translation>
+ 全ての通知は LXQt デスクトップのこの場所に表示されます。</translation>
     </message>
 </context>
 <context>
@@ -125,7 +125,7 @@ These settings won&apos;t have any effect on it!</source>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
         <source>Advanced Settings</source>
-        <translation>高度な設定</translation>
+        <translation>詳細設定</translation>
     </message>
 </context>
 </TS>
