@@ -26,12 +26,16 @@
         <source>Options</source>
         <translation>Volby</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation>%1 nespatřených oznámení</translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n nepřečtené oznámení</numerusform>
+            <numerusform>%n nepřečtená oznámení</numerusform>
+            <numerusform>%n nepřečtených oznámení</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
