@@ -26,12 +26,15 @@
         <source>Options</source>
         <translation>Optionen</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation>%1 Unbeaufsichtigte Benachrichtigung(en)</translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n unbeaufsichtigte Benachrichtigung</numerusform>
+            <numerusform>%n unbeaufsichtigte Benachrichtigungen</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
