@@ -26,12 +26,15 @@
         <source>Options</source>
         <translation>Επιλογές</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation>Ανεπίβλεπτες ειδοποιήσεις: %1</translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n Ανεπίβλεπτη-ες ειδοποίηση-εις</numerusform>
+            <numerusform>%n Ανεπίβλεπτη-ες ειδοποίηση-εις</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
