@@ -26,12 +26,15 @@
         <source>Options</source>
         <translation>Options</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation>%1 Notification(s) sans surveillance</translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n Nouvelle(s) notificattion(s)</numerusform>
+            <numerusform>%n Nouvelles notifications</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
