@@ -6,7 +6,7 @@
     <message>
         <location filename="../notificationwidgets.cpp" line="103"/>
         <source>Actions:</source>
-        <translation>Akciók:</translation>
+        <translation>Műveletek:</translation>
     </message>
     <message>
         <location filename="../notificationwidgets.cpp" line="122"/>
@@ -19,19 +19,22 @@
     <message>
         <location filename="../notifyd.cpp" line="226"/>
         <source>Clear All</source>
-        <translation type="unfinished"></translation>
+        <translation>Tisztítás</translation>
     </message>
     <message>
         <location filename="../notifyd.cpp" line="234"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Beállítások</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation type="unfinished"></translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n olvasatlan értesítés</numerusform>
+            <numerusform>%n olvasatlan értesítés</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
