@@ -6,12 +6,12 @@
     <message>
         <location filename="../notificationwidgets.cpp" line="103"/>
         <source>Actions:</source>
-        <translation></translation>
+        <translation>Handlinger:</translation>
     </message>
     <message>
         <location filename="../notificationwidgets.cpp" line="122"/>
         <source>OK</source>
-        <translation></translation>
+        <translation>Okei</translation>
     </message>
 </context>
 <context>
@@ -26,12 +26,15 @@
         <source>Options</source>
         <translation>Valg</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation>%1 varsler som kjører av seg selv</translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n varsel som ikke er sett</numerusform>
+            <numerusform>%n varsler som ikke er sett</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
