@@ -11,7 +11,7 @@
     <message>
         <location filename="../notificationwidgets.cpp" line="122"/>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation>Oké</translation>
     </message>
 </context>
 <context>
@@ -19,19 +19,22 @@
     <message>
         <location filename="../notifyd.cpp" line="226"/>
         <source>Clear All</source>
-        <translation type="unfinished"></translation>
+        <translation>Wis alles</translation>
     </message>
     <message>
         <location filename="../notifyd.cpp" line="234"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Opties</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="298"/>
-        <location filename="../notifyd.cpp" line="318"/>
-        <source>%1 Unattended Notification(s)</source>
-        <translation type="unfinished"></translation>
+        <location filename="../notifyd.cpp" line="299"/>
+        <location filename="../notifyd.cpp" line="319"/>
+        <source>%n Unattended Notification(s)</source>
+        <translation>
+            <numerusform>%n onafgehandelde notificatie(s)</numerusform>
+            <numerusform>%n onafgehandelde notificaties</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
